@@ -217,10 +217,10 @@ def strtobool(varname, v):
         abort(400, "Unable to parse `%s': %s" % (varname, six.text_type(e)))
 
 
-RESOURCE_DEFAULT_PAGINATION = ['revision_start:asc',
-                               'started_at:asc']
+RESOURCE_DEFAULT_PAGINATION = [u'revision_start:asc',
+                               u'started_at:asc']
 
-METRIC_DEFAULT_PAGINATION = ['id:asc']
+METRIC_DEFAULT_PAGINATION = [u'id:asc']
 
 
 def get_pagination_options(params, default):
@@ -330,8 +330,8 @@ class ArchivePoliciesController(rest.RestController):
             ),
             voluptuous.Required(
                 "aggregation_methods",
-                default=set(conf.archive_policy.default_aggregation_methods)):
-            voluptuous.All(list(valid_agg_methods), voluptuous.Coerce(set)),
+                default=list(conf.archive_policy.default_aggregation_methods)):
+            voluptuous.All(list(valid_agg_methods)),
             voluptuous.Required("definition"): ArchivePolicyDefinitionSchema,
         })
 
